@@ -24,6 +24,28 @@ class TestAWSPublishingMetadata(unittest.TestCase):
                           image_path='/some/fake/path/to/image.raw',
                           image_name='fakeimagename')
 
+    def test_default_snapshot_name(self):
+        """
+        Test that a snapshot name by default is derived from the image
+        filename.
+        """
+        metadata = AWSPublishingMetadata(image_path='/somedir/some-image.raw',
+                                         image_name='fakeimagename',
+                                         container='abcdef')
+
+        self.assertEqual(metadata.snapshot_name, 'some-image')
+
+    def test_explicit_snapshot_name(self):
+        """
+        Test that a snapshot name can be provided explicitly.
+        """
+        metadata = AWSPublishingMetadata(image_path='/somedir/some-image.raw',
+                                         image_name='fakeimagename',
+                                         snapshot_name='mysnapshot',
+                                         container='abcdef')
+
+        self.assertEqual(metadata.snapshot_name, 'mysnapshot')
+
 
 class TestAWSService(unittest.TestCase):
 
@@ -206,6 +228,21 @@ class TestAWSService(unittest.TestCase):
         self.svc.share_image(image, accounts=accounts, groups=groups)
         image.modify_attribute.assert_not_called()
 
+    def test_share_snapshot(self):
+        accounts = ['account1', 'account2']
+
+        snapshot = MagicMock()
+
+        self.svc.share_snapshot(snapshot, accounts=accounts, )
+        snapshot.modify_attribute.assert_called_once_with(
+            Attribute="createVolumePermission",
+            CreateVolumePermission={
+                'Add': [
+                    {'UserId': 'account1'},
+                    {'UserId': 'account2'},
+                ]
+            })
+
     @patch('cloudimg.aws.AWSService.wait_for_import_snapshot_task')
     def test_import_snapshot(self, mock_wait):
         snapshot = mock_wait.return_value = MagicMock()
